pub struct Liftoff {
pub time_s: f64,
pub source: Source,
}Expand description
Liftoff.
Fields
time_s: f64The last sample on the pad, s on the log’s clock: the filtered altitude was within half the altitude’s resolution of the pad then, and rose past it within one sample interval after.
source: SourceWhere it came from.